@@ -1,32 +1,39 @@
-from __future__ import absolute_import, unicode_literals
+__all__ = ["ApiGroup"]
 
-__all__ = ['APIWrapper']
+from typing import Callable, Optional, TypeVar
+
+from arango.connection import Connection
+from arango.executor import ApiExecutor
+from arango.request import Request
+from arango.response import Response
+from arango.result import Result
+
+T = TypeVar("T")
 
 
-class APIWrapper(object):
-    """Base class for API wrappers.
+class ApiGroup:
+    """Base class for API groups.
 
     :param connection: HTTP connection.
-    :type connection: arango.connection.Connection
     :param executor: API executor.
-    :type executor: arango.executor.Executor
     """
 
-    def __init__(self, connection, executor):
+    def __init__(self, connection: Connection, executor: ApiExecutor) -> None:
         self._conn = connection
         self._executor = executor
 
     @property
-    def conn(self):
-        """Return HTTP connection object.
+    def conn(self) -> Connection:
+        """Return the HTTP connection.
 
         :return: HTTP connection.
-        :rtype: arango.connection.Connection
+        :rtype: arango.connection.BasicConnection | arango.connection.JwtConnection |
+            arango.connection.JwtSuperuserConnection
         """
         return self._conn
 
     @property
-    def db_name(self):
+    def db_name(self) -> str:
         """Return the name of the current database.
 
         :return: Database name.
@@ -35,7 +42,7 @@ class APIWrapper(object):
         return self._conn.db_name
 
     @property
-    def username(self):
+    def username(self) -> Optional[str]:
         """Return the username.
 
         :returns: Username.
@@ -44,7 +51,7 @@ class APIWrapper(object):
         return self._conn.username
 
     @property
-    def context(self):
+    def context(self) -> str:
         """Return the API execution context.
 
         :return: API execution context. Possible values are "default", "async",
@@ -53,14 +60,15 @@ class APIWrapper(object):
         """
         return self._executor.context
 
-    def _execute(self, request, response_handler):
-        """Execute an API per execution context.
+    def _execute(
+        self, request: Request, response_handler: Callable[[Response], T]
+    ) -> Result[T]:
+        """Execute an API.
 
         :param request: HTTP request.
         :type request: arango.request.Request
         :param response_handler: HTTP response handler.
         :type response_handler: callable
         :return: API execution result.
-        :rtype: str | bool | int | list | dict
         """
         return self._executor.execute(request, response_handler)
